package cp_r

import (
	"git.hilo.cn/hilo-common/domain"
	"git.hilo.cn/hilo-common/mycontext"
	"git.hilo.cn/hilo-common/resource/mysql"
	"github.com/gin-gonic/gin"
	"hilo-user/_const/enum/cp_e"
	"hilo-user/cv/cp_cv"
	"hilo-user/cv/user_cv"
	"hilo-user/domain/model/user_m"
	"hilo-user/myerr/bizerr"
	"hilo-user/req"
	"hilo-user/resp"
)

// @Tags CP v2
// @Summary cp空间
// @Param token header string true "token"
// @Param nonce header string true "随机数字"
// @Param externalId query string true "查看用户的externalId"
// @Success 200 {object} cp_cv.CvSpace
// @Router /v2/cp/space [get]
func CpSpace(c *gin.Context) (*mycontext.MyContext, error) {
	myContext := mycontext.CreateMyContext(c.Keys)
	userId, lang, err := req.GetUserIdLang(c, myContext)
	if err != nil {
		return myContext, err
	}
	externalId := c.Query("externalId")
	if len(externalId) <= 0 {
		return myContext, bizerr.InvalidParameter
	}
	var model = domain.CreateModelContext(myContext)
	userInfo, err := user_m.GetUser(model, userId)
	if err != nil {
		return myContext, err
	}
	cpUserInfo, err := user_m.GetUserByExtId(model, externalId) // todo get from cp2 db
	if err != nil {
		return myContext, err
	}
	expireAt := ""           // todo
	cpGrade := cp_e.CpGrade3 // todo get from db
	nextExp := cp_e.CpGradeExp[cp_e.CpGradeMax]
	remainExp := mysql.Num(0)
	if cpGrade != cp_e.CpGradeMax {
		nextExp = cp_e.CpGradeExp[cpGrade+1]
		remainExp = nextExp - cp_e.CpGradeExp[cpGrade] // todo get from db
	}
	response := cp_cv.CvSpace{
		CpInfo: cp_cv.CvCpInfo{
			UserInfo:   user_cv.UserToTiny(*userInfo),
			CpUserInfo: user_cv.UserToTiny(*cpUserInfo),
		},
		CpGrade: cp_cv.CvCpGrade{
			Grade:     cpGrade,
			Exp:       cp_e.CpGradeExp[cpGrade], // todo get from db
			NextExp:   nextExp,
			RemainExp: remainExp,
			ExpireAt:  expireAt,
		},
		ResGradeList:  cp_cv.CvResGradeList,
		PrivilegeList: cp_cv.CopyCpGradePrivilegeList(cpGrade, lang),
	}
	resp.ResponseOk(c, response)
	return myContext, nil
}
